BanzaiDB — BanzaiDB 0.1.1 documentation

### Navigation

- index
- modules |
- next |
- BanzaiDB 0.1.1 documentation »

# BanzaiDB

BanzaiDB is a tool for pairing Microbial Genomics Next Generation Sequencing (NGS) analysis with a NoSQL database. We use the RethinkDB NoSQL database.

BanzaiDB:
  - initalises the NoSQL database and associated tables,
  - populates the database with results of NGS experiments/analysis and,
  - provides a set of query functions to wrangle with the data stored within the database.

## BanzaiDB documentation contents

### User documentation

Learn how to initalise a database, populate the database and query it!

- Installing BanzaiDB
- Initialising your first BanzaiDB database
- Getting study metadata into BanzaiDB

### API documentation

Explore the available methods within BanzaiDB.

- BanzaiDB

### Developer documentation

Learn how to contribute to the development of BanzaiDB.

- BanzaiDB Developer HOWTO

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- BanzaiDB 0.1.1 documentation »